# ******************************************************
# *
# * Name:         step02-create-blob-storage.ps1
# *     
# * Design Phase:
# *     Author:   John Miner
# *     Date:     01-10-2018
# *     Purpose:  Create two containers and load sample
# *               stock data.  Create a shared 
# *               access signature for use later.
# * 
# ******************************************************


#
# Azure Subscriptions 
#

# Prompts you for azure credentials
Add-AzureRmAccount

# Clear the screen
Clear-Host

# List my subscriptions
Get-AzureRmSubscription

# Pick my internal subscription
$SubscriptionId = 'cdfb69bf-3533-4c89-9684-1ba6ba81b226'
Set-AzureRmContext -SubscriptionId $SubscriptionId



#
# Create a resource group
#

# New resource group
New-AzureRmResourceGroup -Name "rg4ssug" -Location "East US 2"

# Clear the screen
Clear-Host

# List resource groups
Get-AzureRmResourceGroup -Name "rg4ssug"

# Delete resource group
# Remove-AzureRmResourceGroup -Name "rg4ssug" -Force



#
# Create a storage account
#

# Create new storage account (lowercase)
New-AzureRmStorageAccount StorageAccountName 'sa4ssug' -ResourceGroupName "rg4ssug" -Location "East US 2" -Type "Standard_GRS"

# Clear the screen
Clear-Host

# Show the account
$A = Get-AzureRmStorageAccount 
$A.Sku
$A.Type

# Delete storage account
#Remove-AzureRmStorageAccount -ResourceGroupName "rg4ssug" -Name 'sa4ssug' 



#
# Create a storage container(s)
#

# Grab storage context - work around for RM
$StorageContext = Get-AzureRmStorageAccount -Name 'sa4ssug' -ResourceGroupName "rg4ssug" 

# Create new containers
$StorageContext | New-AzureStorageContainer -Name "sc4inbox" -Permission Off
$StorageContext | New-AzureStorageContainer -Name 'sc4archive' -Permission Off

# Clear the screen
Clear-Host

# Show the container
$StorageContext | Get-AzureStorageContainer 
 
# Remove the container
# $StorageContext | Remove-AzureStorageContainer -Name "sc4inbox" -Force
# $StorageContext | Remove-AzureStorageContainer -Name 'sc4archive' -Force



#
# Upload files to azure (stocks)
#

# Grab storage context - work around for RM
$StorageContext = Get-AzureRmStorageAccount -Name 'sa4ssug' -ResourceGroupName "rg4ssug" 

# Set source path
$srcpath = "C:\COMMUNITY WORK\STAGING\DATA\S&P-2013\"

# Set counter
$cnt = 0

# Local file path
$list = Get-ChildItem $srcpath -Filter *.csv 

# For each stock
foreach ($file in $list)
{
    # file names
    $localname = $srcpath + $file.Name
    $remotename = "NEW/" + $file.name

    # Upload file to azure
    $StorageContext | Set-AzureStorageBlobContent -Container "sc4inbox" -File $localname -Blob $remotename -Force

    # Increment count
    Write-Host $srcfull
    Write-Host $cnt
    $cnt = $cnt + 1
}



#
# Upload master stock list
#

# Grab storage context - work around for RM
$StorageContext = Get-AzureRmStorageAccount -Name 'sa4ssug' -ResourceGroupName "rg4ssug" 

# Set source path
$srcpath = "C:\COMMUNITY WORK\STAGING\DATA\S&P-2013\"
$filename = "PACKING-LIST.TXT"

# File names
$localname = $srcpath + $filename
$remotename = "NEW/" + $filename

# Upload file to azure
$StorageContext | Set-AzureStorageBlobContent -Container "sc4inbox" -File $localname -Blob $remotename -Force



#
# List all blobs in the container
#


# List all blobs in a container.
$StorageContext | Get-AzureStorageBlob -Container "sc4inbox" 



#
# Download file from azure
#

$StorageContext | Get-AzureStorageBlob -Container "sc4inbox" -Blob "PACKING-LIST.TXT" | Get-AzureStorageBlobContent -Destination "c:\temp\"



#
# Create Shared Access Signature (SAS)
#

# Grab storage context - work around for RM
$StorageContext = Get-AzureRmStorageAccount -Name "sa4ssug" -ResourceGroupName "rg4ssug" 

# Sets up a Stored Access Policy and a Shared Access Signature for the new container  
$Policy = $StorageContext | New-AzureStorageContainerStoredAccessPolicy -Container "sc4inbox" -Policy "pol4inbox" `
  -StartTime $(Get-Date).ToUniversalTime().AddMinutes(-5) -ExpiryTime $(Get-Date).ToUniversalTime().AddYears(10) -Permission rwld

# Gets the Shared Access Signature for the policy  
$SAS = $StorageContext | New-AzureStorageContainerSASToken -name "sc4inbox" -Policy "pol4inbox" 
Write-Host 'Shared Access Signature= '$($SAS.Substring(1))''  

<#

 sv=2017-04-17&sr=c&si=pol4inbox&sig=CuINwl6%2Falc6jEvUFI1yTV4fUVEZmCuBVr%2Fr%2BSQWRbc%3D 

#>