# ******************************************************
# *
# * Name:         step06-create-azure-sql-dw.ps1
# *     
# * Design Phase:
# *     Author:   John Miner
# *     Date:     08-08-2017
# *     Purpose:  Create azure sql database dw 
# *               using resource manager.
# * 
# ******************************************************


#
# Azure Subscriptions 
#

# Prompts you for azure credentials
Add-AzureRmAccount

# Clear the screen
Clear-Host

# List my subscriptions
Get-AzureRmSubscription

# Pick my internal subscription
# $SubscriptionId = 'cdfb69bf-3533-4c89-9684-1ba6ba81b226'
# Set-AzureRmContext -SubscriptionId $SubscriptionId



#
# Data Centers with my service
#

# Clear the screen
Clear-Host

# Data centers with Azure SQL database
$AzureSQLLocations = (Get-AzureRmResourceProvider -ListAvailable | 
    Where-Object {$_.ProviderNamespace -eq 'Microsoft.Sql'}).Locations
$AzureSQLLocations




#
# Create a resource group
#

# New resource group
#New-AzureRmResourceGroup -Name "rg4ssug" -Location "East US 2"

# Clear the screen
Clear-Host

# List resource groups
Get-AzureRmResourceGroup -Name "rg4ssug"

# Delete resource group
# Remove-AzureRmResourceGroup -Name "rg4ssug" -Force



#
# Create a new server
#

# Create a credential
#$User = "jminer"
#$Pword = ConvertTo-SecureString String 'RI#SsUg$2018' AsPlainText -Force
#$Credential = New-Object TypeName System.Management.Automation.PSCredential ArgumentList $User, $Pword

# New sql server
#New-AzureRmSqlServer -ResourceGroupName "rg4ssug" -ServerName "svr4ssug" -Location "East US" -SqlAdministratorCredentials $Credential

# Clear the screen
Clear-Host

# List Sql Servers
Get-AzureRmSqlServer -ResourceGroupName "rg4ssug"

# Remove the sql server
#Remove-AzureRmSqlServer -ResourceGroupName "rg4ssug" -ServerName "svr4ssug" 



#
# Add laptop ip to firewall (todo = code to figure out ip since I am behind a router)
#

# External ip
# $MyIp = (Invoke-WebRequest ifconfig.me/ip).Content -replace "`n","" 

# Create new firewall rule
# New-AzureRmSqlServerFirewallRule -ResourceGroupName "rg4ssug" -ServerName "svr4ssug" -FirewallRuleName "fr4laptop" -StartIpAddress "$MyIp" -EndIpAddress "$MyIp"

# Clear the screen
Clear-Host

# List firewall rules
Get-AzureRmSqlServerFirewallRule -ResourceGroupName "rg4ssug" -ServerName "svr4ssug"


# Remove firewall rule
# Remove-AzureRmSqlServerFirewallRule -ResourceGroupName "rg4ssug" -ServerName "svr4ssug" -FirewallRuleName "fr4laptop"




#
# Make the new database
#

# Give database size quota
$TenTb = (1024 * 1024 * 1024 * 1024 * 10)
$TenTb

# Create a new database
New-AzureRmSqlDatabase -RequestedServiceObjectiveName "DW100" -DatabaseName "dw4stocks" `
    -ServerName "svr4ssug" -ResourceGroupName "rg4ssug" -Edition "DataWarehouse" `
    -CollationName "SQL_Latin1_General_CP1_CI_AS" -MaxSizeBytes $TenTb

# Clear the screen
Clear-Host

# List the new database
Get-AzureRmSqlDatabase -ResourceGroupName "rg4ssug" -ServerName "dw4stocks"


# Remove the database
# Remove-AzureRmSqlDatabase -ResourceGroupName "rg4ssug" -ServerName "svr4ssug" -DatabaseName "dw4stocks"



#
# Change the database size (DW1000)
#

# Log into Azure
Login-AzureRmAccount

# Clear the screen
Clear-Host

# Give database size quota
Set-AzureRmSqlDatabase -ResourceGroupName "rg4ssug" -ServerName "svr4ssug"  `
  -DatabaseName "dw4stocks" -Edition "DataWarehouse" -RequestedServiceObjectiveName "DW1000"



#
# Pause the compute charges
#


$dbinfo = Get-AzureRmSqlDatabase ResourceGroupName "rg4ssug" ServerName "svr4ssug" DatabaseName "dw4stocks"
$result = $dbinfo | Suspend-AzureRmSqlDatabase
$result



#
# Resume the compute charges
#


$dbinfo = Get-AzureRmSqlDatabase ResourceGroupName "rg4ssug" ServerName "svr4ssug" DatabaseName "dw4stocks"
$result = $dbinfo | Resume-AzureRmSqlDatabase
$result