﻿# ******************************************************
# *
# * Name:         step09-azure-automation-objects.ps1
# *     
# * Design Phase:
# *     Author:   John Miner
# *     Date:     01-10-2018
# *     Purpose:  Automate the load and archive data workflow.
# *
# *     Note:     Manually punch firewall hole for azure svcs.
# * 
# ******************************************************

<#
    Azure Automation Cmdlets
    https://msdn.microsoft.com/en-us/library/mt244122.aspx
#>


#
# Name:      Create-PSCredential
# Purpose:   Create a secure credential.
#

Function Create-PSCredential { 
 
    [CmdletBinding()] 
    Param( 
 
        [Parameter(Mandatory = $true)] 
        [string]$Username, 
 
        [Parameter(Mandatory = $true)] 
        [string]$Password  
 
    )   
 
    $SecurePassword = ConvertTo-SecureString $Password -AsPlainText -Force 
    $Credential = New-Object System.Management.Automation.PSCredential ($Username, $SecurePassword) 
    Return $Credential 
} 
 


#
# Azure Subscriptions 
#

# Prompts you for azure credentials
Add-AzureRmAccount

# Clear the screen
Clear-Host

# List my subscriptions
Get-AzureRmSubscription

# Pick my internal subscription
$SubscriptionId = 'cdfb69bf-3533-4c89-9684-1ba6ba81b226'
Set-AzureRmContext -SubscriptionId $SubscriptionId



#
# Create automation account
#

# Create account
New-AzureAutomationAccount -Name "aa4ssug" -Location "East US"

# List automation accounts
Get-AzureAutomationAccount 

# Delete automation accounts
# Remove-AzureAutomationAccount -Name "aa4ssug"



#
# Create credential for sqldb
#

$Credential = Create-PSCredential -Username "jminer" -Password 'RI#SsUg$2018'
New-AzureAutomationCredential -AutomationAccountName "aa4ssug" -Name "SqlCredential" -Value $Credential 

# List saved credential
Get-AzureAutomationCredential -AutomationAccountName "aa4ssug"

# Delete saved credential
# Remove-AzureAutomationCredential -AutomationAccountName "aa4ssug" -Name "SqlCredential"

<#
  $Credential.UserName
  $Credential.Password
  $Credential.GetNetworkCredential().Password
#>



#
# Create runbook from ps workflow
#

# Empty run book
$RunBook = "load-and-archive-data"
New-AzureAutomationRunbook -AutomationAccountName "aa4ssug" -Name $RunBook 

# Add local workflow
$Path = "C:\Community Work\STAGING\CODE\load-and-archive-data.ps1"
Set-AzureAutomationRunbookDefinition -AutomationAccountName "aa4ssug" -Name $RunBook  -Path $Path -Overwrite

# Publish work flow
Publish-AzureAutomationRunbook -AutomationAccountName "aa4ssug" -Name $RunBook 

# List saved runbook
# Get-AzureAutomationRunbook -AutomationAccountName "aa4ssug" -Name $RunBook 

# Delete save runbook
# Remove-AzureAutomationRunbook -AutomationAccountName "aa4ssug" -Name $RunBook  



#
# Create a schedule (asset)
#

$Schedule = "schd-load-and-archive-data"
New-AzureAutomationSchedule -AutomationAccountName "aa4ssug" -Name $Schedule -DayInterval 1 -StartTime  "20:00:00"

# List saved schedule
# Get-AzureAutomationSchedule -AutomationAccountName "aa4ssug" -Name $Schedule 

# Delete saved schedule
# Remove-AzureAutomationSchedule -AutomationAccountName "aa4ssug" -Name $Schedule



#
# Link schedule to runbook (bug with MSFT!!)
#

#  Add schedule to runbook
$Account = "aa4ssug"
$RunBook = "load-and-archive-data"
$Schedule = "schd-load-and-archive-data"
Register-AzureAutomationScheduledRunbook –AutomationAccountName $Account –Name $RunBook –ScheduleName $Schedule


# Account is linked
Get-AzureAutomationScheduledRunbook -AutomationAccountName $Account


#
# Disable schedule
#

Set-AzureAutomationSchedule –AutomationAccountName $Account –Name $Schedule –IsEnabled $false